@@ -89,11 +89,23 @@ static bool isPlausibleFlightTime(const QDateTime &fromTime, const QDateTime &to
     return fromDt < toDt && FlightUtil::isPlausibleDistanceForDuration(distance, flightDuration);
 }
 
+static bool conflictIfSet(const QDateTime &lhs, const QDateTime &rhs)
+{
+    return lhs.isValid() && rhs.isValid() && lhs != rhs;
+}
+
 static void applyFlightTimes(QVector<QVariant> &result, const QDateTime &boarding, const QDateTime &dep, const QDateTime &arr)
 {
     for (auto &res : result) {
         auto flightRes = res.value<FlightReservation>();
         auto flight = flightRes.reservationFor().value<Flight>();
+
+        // check if already set times match, otherwise discard the entire set
+        if (conflictIfSet(flight.boardingTime(), boarding) || conflictIfSet(flight.departureTime(), dep) || conflictIfSet(flight.arrivalTime(), arr)) {
+            continue;
+        }
+
+        // apply not yet set times
         if (!flight.boardingTime().isValid() && boarding.isValid()) {
             flight.setBoardingTime(boarding);
         }
